Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(441)

Unified Diff: webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h

Issue 2479153002: Rename media constraints model and store. (Closed)
Patch Set: Rebase master Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h
diff --git a/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h b/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h
index 91b9fc94a538bfb80fc041f40de7d6e8ae258121..f979655c89d00ad21167b13c573805b026bd4c54 100644
--- a/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h
+++ b/webrtc/examples/objc/AppRTCMobile/ios/ARDSettingsViewController.h
@@ -10,7 +10,7 @@
#import <UIKit/UIKit.h>
-@class ARDMediaConstraintsModel;
+@class ARDSettingsModel;
NS_ASSUME_NONNULL_BEGIN
/**
@@ -22,10 +22,10 @@ NS_ASSUME_NONNULL_BEGIN
* Creates new instance.
*
* @param style the table view style that should be used
* @param mediaConstraintsModel model class for the media constraints settings.
*/
- (instancetype)initWithStyle:(UITableViewStyle)style
- mediaConstraintsModel:(ARDMediaConstraintsModel *)mediaConstraintsModel;
+ settingsModel:(ARDSettingsModel *)settingsModel;
#pragma mark - Unavailable

Powered by Google App Engine
@@ -22,10 +22,10 @@ NS_ASSUME_NONNULL_BEGIN
*
* @param style the table view style that should be used
- * @param mediaConstraintsModel model class for the media constraints settings.
+ * @param settingsModel model class for the user settings.
*/
This is Rietveld 408576698